@@ -12,20 +12,18 @@ from .const import (
     ARISTON_DATA_ITEMS,
     ARISTON_LITE,
     ARISTON_LOGIN,
-    ARISTON_MED_PLANT_DATA,
     ARISTON_PLANT_DATA,
     ARISTON_PLANTS,
     ARISTON_REMOTE,
     ARISTON_REPORTS,
-    ARISTON_SE_PLANT_DATA,
-    ARISTON_SLP_PLANT_DATA,
     ARISTON_TIME_PROGS,
     ARISTON_VELIS,
     DeviceFeatures,
     DeviceProperties,
-    EvoPlantMode,
     LydosPlantMode,
+    WaterHeaterMode,
     NuosSplitOperativeMode,
+    PlantData,
     ThermostatProperties,
     ZoneAttribute,
 )
@@ -177,17 +175,19 @@ class AristonAPI:
             return properties
         return dict()
 
-    def get_velis_plant_data(self, plant_data: str, gw_id: str) -> dict[str, Any]:
+    def get_velis_plant_data(self, plant_data: PlantData, gw_id: str) -> dict[str, Any]:
         """Get Velis properties"""
-        data = self._get(f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data}/{gw_id}")
+        data = self._get(f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data.value}/{gw_id}")
         if data is not None:
             return data
         return dict()
 
-    def get_velis_plant_settings(self, plant_data: str, gw_id: str) -> dict[str, Any]:
+    def get_velis_plant_settings(
+        self, plant_data: PlantData, gw_id: str
+    ) -> dict[str, Any]:
         """Get Velis settings"""
         settings = self._get(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data}/{gw_id}/plantSettings"
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data.value}/{gw_id}/plantSettings"
         )
         if settings is not None:
             return settings
@@ -219,10 +219,10 @@ class AristonAPI:
             },
         )
 
-    def set_evo_mode(self, gw_id: str, value: EvoPlantMode) -> None:
+    def set_evo_mode(self, gw_id: str, value: WaterHeaterMode) -> None:
         """Set Velis Evo mode"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_MED_PLANT_DATA}/{gw_id}/mode",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Med.value}/{gw_id}/mode",
             {
                 "new": value.value,
             },
@@ -231,7 +231,7 @@ class AristonAPI:
     def set_lydos_mode(self, gw_id: str, value: LydosPlantMode) -> None:
         """Set Velis Lydos mode"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SE_PLANT_DATA}/{gw_id}/mode",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Se.value}/{gw_id}/mode",
             {
                 "new": value.value,
             },
@@ -240,7 +240,7 @@ class AristonAPI:
     def set_nuos_mode(self, gw_id: str, value: NuosSplitOperativeMode) -> None:
         """Set Velis Nuos mode"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SLP_PLANT_DATA}/{gw_id}/operativeMode",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Slp.value}/{gw_id}/operativeMode",
             {
                 "new": value.value,
             },
@@ -249,7 +249,7 @@ class AristonAPI:
     def set_evo_temperature(self, gw_id: str, value: float) -> None:
         """Set Velis Evo temperature"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_MED_PLANT_DATA}/{gw_id}/temperature",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Med.value}/{gw_id}/temperature",
             {
                 "new": value,
             },
@@ -258,7 +258,7 @@ class AristonAPI:
     def set_lydos_temperature(self, gw_id: str, value: float) -> None:
         """Set Velis Lydos temperature"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SE_PLANT_DATA}/{gw_id}/temperature",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Se.value}/{gw_id}/temperature",
             {
                 "new": value,
             },
@@ -267,7 +267,7 @@ class AristonAPI:
     def set_nuos_temperature(self, gw_id: str, comfort: float, reduced: float) -> None:
         """Set Nuos temperature"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SLP_PLANT_DATA}/{gw_id}/temperatures",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Slp.value}/{gw_id}/temperatures",
             {
                 "new": {
                     "comfort": comfort,
@@ -279,27 +279,27 @@ class AristonAPI:
     def set_nous_boost(self, gw_id: str, boost: bool) -> None:
         """ "Set Nous boost"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SLP_PLANT_DATA}/{gw_id}/boost",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Slp.value}/{gw_id}/boost",
             boost,
         )
 
     def set_evo_eco_mode(self, gw_id: str, eco_mode: bool) -> None:
         """Set Velis Evo eco mode"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_MED_PLANT_DATA}/{gw_id}/switchEco",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Med.value}/{gw_id}/switchEco",
             eco_mode,
         )
 
-    def set_velis_power(self, plant_data: str, gw_id: str, power: bool) -> None:
+    def set_velis_power(self, plant_data: PlantData, gw_id: str, power: bool) -> None:
         """Set Velis power"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data}/{gw_id}/switch",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data.value}/{gw_id}/switch",
             power,
         )
 
     def set_velis_plant_setting(
         self,
-        plant_data: str,
+        plant_data: PlantData,
         gw_id: str,
         setting: str,
         value: float,
@@ -307,7 +307,7 @@ class AristonAPI:
     ) -> None:
         """Set Velis plant setting"""
         self._post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data}/{gw_id}/plantSettings",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data.value}/{gw_id}/plantSettings",
             {setting: {"new": value, "old": old_value}},
         )
 
@@ -347,11 +347,10 @@ class AristonAPI:
         headers = {"ar.authToken": self.__token}
 
         _LOGGER.debug(
-            "Request method %s, path: %s, params: %s, body: %s",
+            "Request method %s, path: %s, params: %s",
             method,
             path,
             params,
-            body,
         )
         response = requests.request(
             method, path, params=params, json=body, headers=headers
@@ -497,22 +496,22 @@ class AristonAPI:
         return dict()
 
     async def async_get_velis_plant_data(
-        self, plant_data: str, gw_id: str
+        self, plant_data: PlantData, gw_id: str
     ) -> dict[str, Any]:
         """Async get Velis properties"""
         med_plant_data = await self._async_get(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data}/{gw_id}"
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data.value}/{gw_id}"
         )
         if med_plant_data is not None:
             return med_plant_data
         return dict()
 
     async def async_get_velis_plant_settings(
-        self, plant_data: str, gw_id: str
+        self, plant_data: PlantData, gw_id: str
     ) -> dict[str, Any]:
         """Async get Velis settings"""
         med_plant_settings = await self._async_get(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data}/{gw_id}/plantSettings"
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data.value}/{gw_id}/plantSettings"
         )
         if med_plant_settings is not None:
             return med_plant_settings
@@ -544,10 +543,10 @@ class AristonAPI:
             },
         )
 
-    async def async_set_evo_mode(self, gw_id: str, value: EvoPlantMode) -> None:
+    async def async_set_evo_mode(self, gw_id: str, value: WaterHeaterMode) -> None:
         """Async set Velis Evo mode"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_MED_PLANT_DATA}/{gw_id}/mode",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Med.value}/{gw_id}/mode",
             {
                 "new": value.value,
             },
@@ -556,7 +555,7 @@ class AristonAPI:
     async def async_set_lydos_mode(self, gw_id: str, value: LydosPlantMode) -> None:
         """Async set Velis Lydos mode"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SE_PLANT_DATA}/{gw_id}/mode",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Se.value}/{gw_id}/mode",
             {
                 "new": value.value,
             },
@@ -567,7 +566,7 @@ class AristonAPI:
     ) -> None:
         """Async set Velis Nuos mode"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SLP_PLANT_DATA}/{gw_id}/operativeMode",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Slp.value}/{gw_id}/operativeMode",
             {
                 "new": value.value,
             },
@@ -576,7 +575,7 @@ class AristonAPI:
     async def async_set_evo_temperature(self, gw_id: str, value: float) -> None:
         """Async set Velis Evo temperature"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_MED_PLANT_DATA}/{gw_id}/temperature",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Med.value}/{gw_id}/temperature",
             {
                 "new": value,
             },
@@ -585,7 +584,7 @@ class AristonAPI:
     async def async_set_lydos_temperature(self, gw_id: str, value: float) -> None:
         """Async set Velis Lydos temperature"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SE_PLANT_DATA}/{gw_id}/temperature",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Se.value}/{gw_id}/temperature",
             {
                 "new": value,
             },
@@ -596,7 +595,7 @@ class AristonAPI:
     ) -> None:
         """Async set Velis Lydos temperature"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SLP_PLANT_DATA}/{gw_id}/temperatures",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Slp.value}/{gw_id}/temperatures",
             {
                 "new": {
                     "comfort": comfort,
@@ -608,29 +607,29 @@ class AristonAPI:
     async def async_set_nous_boost(self, gw_id: str, boost: bool) -> None:
         """ "Set Nous boost"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_SLP_PLANT_DATA}/{gw_id}/boost",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Slp.value}/{gw_id}/boost",
             boost,
         )
 
     async def async_set_evo_eco_mode(self, gw_id: str, eco_mode: bool) -> None:
         """Async set Velis Evo eco mode"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{ARISTON_MED_PLANT_DATA}/{gw_id}/switchEco",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{PlantData.Med.value}/{gw_id}/switchEco",
             eco_mode,
         )
 
     async def async_set_velis_power(
-        self, plant_data: str, gw_id: str, power: bool
+        self, plant_data: PlantData, gw_id: str, power: bool
     ) -> None:
         """Async set Velis power"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data}/{gw_id}/switch",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data.value}/{gw_id}/switch",
             power,
         )
 
     async def async_set_velis_plant_setting(
         self,
-        plant_data: str,
+        plant_data: PlantData,
         gw_id: str,
         setting: str,
         value: float,
@@ -638,7 +637,7 @@ class AristonAPI:
     ) -> None:
         """Async set Velis Evo plant setting"""
         await self._async_post(
-            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data}/{gw_id}/plantSettings",
+            f"{ARISTON_API_URL}{ARISTON_VELIS}/{plant_data.value}/{gw_id}/plantSettings",
             {setting: {"new": value, "old": old_value}},
         )
 
@@ -676,11 +675,10 @@ class AristonAPI:
         headers = {"ar.authToken": self.__token}
 
         _LOGGER.debug(
-            "Request method %s, path: %s, params: %s, body: %s",
+            "Request method %s, path: %s, params: %s",
             method,
             path,
             params,
-            body,
         )
 
         async with aiohttp.ClientSession() as session:
