@@ -1,4 +1,4 @@
-from enum import Enum, IntFlag, unique
+from enum import Enum, unique
 from typing import Final
 
 ARISTON_API_URL: Final[str] = "https://www.ariston-net.remotethermo.com/api/v2/"
@@ -10,15 +10,21 @@ ARISTON_LITE: Final[str] = "lite"
 ARISTON_DATA_ITEMS: Final[str] = "dataItems"
 ARISTON_ZONES: Final[str] = "zones"
 ARISTON_PLANT_DATA: Final[str] = "plantData"
-ARISTON_MED_PLANT_DATA: Final[str] = "medPlantData"
-ARISTON_SE_PLANT_DATA: Final[str] = "sePlantData"
-ARISTON_SLP_PLANT_DATA: Final[str] = "slpPlantData"
 ARISTON_REPORTS: Final[str] = "reports"
 ARISTON_TIME_PROGS: Final[str] = "timeProgs"
 
 
 @unique
-class PlantMode(IntFlag):
+class PlantData(str, Enum):
+    """Plant data enum"""
+
+    Med = "medPlantData"
+    Se = "sePlantData"
+    Slp = "slpPlantData"
+
+
+@unique
+class PlantMode(Enum):
     """Plant mode enum"""
 
     UNDEFINED = -1
@@ -32,7 +38,7 @@ class PlantMode(IntFlag):
 
 
 @unique
-class ZoneMode(IntFlag):
+class ZoneMode(Enum):
     """Zone mode enum"""
 
     UNDEFINED = -1
@@ -43,7 +49,7 @@ class ZoneMode(IntFlag):
 
 
 @unique
-class DhwMode(IntFlag):
+class DhwMode(Enum):
     """Dhw mode enum"""
 
     DISABLED = 0
@@ -55,7 +61,7 @@ class DhwMode(IntFlag):
 
 
 @unique
-class Weather(IntFlag):
+class Weather(Enum):
     """Weather enum"""
 
     UNAVAILABLE = 0
@@ -72,7 +78,7 @@ class Weather(IntFlag):
 
 
 @unique
-class GasEnergyUnit(IntFlag):
+class GasEnergyUnit(Enum):
     """Gas energy unit enum"""
 
     KWH = 0
@@ -84,7 +90,7 @@ class GasEnergyUnit(IntFlag):
 
 
 @unique
-class GasType(IntFlag):
+class GasType(Enum):
     """Gas type enu,"""
 
     NATURAL_GAS = 0
@@ -95,7 +101,7 @@ class GasType(IntFlag):
 
 
 @unique
-class Currency(IntFlag):
+class Currency(Enum):
     """Currency enum"""
 
     ARS = 1
@@ -121,7 +127,7 @@ class Currency(IntFlag):
 
 
 @unique
-class SystemType(IntFlag):
+class SystemType(Enum):
     """System type enum"""
 
     UNKNOWN = -1
@@ -133,7 +139,7 @@ class SystemType(IntFlag):
 
 
 @unique
-class Brands(IntFlag):
+class Brands(Enum):
     """Brands enum"""
 
     Ariston = 1
@@ -149,6 +155,15 @@ class WaterHeaterMode(Enum):
     """Base class for plant modes"""
 
 
+@unique
+class LuxPlantMode(WaterHeaterMode):
+    """Lux plant mode enum"""
+
+    MANUAL = 1
+    PROGRAM = 5
+    BOOST = 9
+
+
 @unique
 class EvoPlantMode(WaterHeaterMode):
     """Evo plant mode enum"""
@@ -195,17 +210,19 @@ class LydosPlantMode(WaterHeaterMode):
 
 
 @unique
-class WheType(IntFlag):
+class WheType(Enum):
     """Whe type enum"""
 
     Unknown = -1
+    Evo = 1
     LydosHybrid = 2
     NuosSplit = 4
-    Evo = 6
+    Evo2 = 6
+    Lux = 8
 
 
 @unique
-class ConsumptionType(IntFlag):
+class ConsumptionType(Enum):
     """Consumption type"""
 
     CENTRAL_HEATING_TOTAL_ENERGY = 1
@@ -219,7 +236,7 @@ class ConsumptionType(IntFlag):
 
 
 @unique
-class ConsumptionTimeInterval(IntFlag):
+class ConsumptionTimeInterval(Enum):
     """Consumption time interval"""
 
     # I am not sure. This is just a guess.
