@@ -283,6 +283,10 @@ class AristonGalevoDevice(AristonDevice):
     def get_is_flame_on_value(self) -> bool:
         """Get is flame on value"""
         return self._get_item_by_id(DeviceProperties.IS_FLAME_ON, PropertyType.VALUE)
+        
+    def get_is_heating_pump_on_value(self) -> bool:                              
+        """Get is heating pump on value"""                                           
+        return self._get_item_by_id(DeviceProperties.IS_HEATING_PUMP_ON, PropertyType.VALUE)
 
     def get_holiday_mode_value(self) -> bool:
         """Get holiday mode on value"""
@@ -330,10 +334,14 @@ class AristonGalevoDevice(AristonDevice):
 
     def get_plant_mode_text(self) -> str:
         """Get plant mode on option texts"""
-        index = self.get_plant_mode_options().index(self.get_plant_mode())
-        return self._get_item_by_id(
-            DeviceProperties.PLANT_MODE, PropertyType.OPT_TEXTS
-        )[index]
+        current_plant_mode = self.get_plant_mode().value
+        plant_mode_options = self.get_plant_mode_options()
+        if current_plant_mode in plant_mode_options:
+            index = plant_mode_options.index(current_plant_mode)
+            return self._get_item_by_id(
+                DeviceProperties.PLANT_MODE, PropertyType.OPT_TEXTS
+            )[index]
+        return PlantMode.UNDEFINED.name
 
     def get_measured_temp_unit(self, zone: int) -> str:
         """Get zone measured temp unit"""
@@ -474,7 +482,7 @@ class AristonGalevoDevice(AristonDevice):
     def get_gas_type(self) -> Optional[str]:
         """Get gas type"""
         gas_type = self.consumptions_settings.get(ConsumptionProperties.GAS_TYPE)
-        if gas_type in dir(GasType):
+        if gas_type in list(GasType):
             return GasType(gas_type).name
         return None
 
@@ -486,19 +494,19 @@ class AristonGalevoDevice(AristonDevice):
     def set_gas_type(self, selected: str):
         """Set gas type"""
         self._set_consumptions_settings(
-            ConsumptionProperties.GAS_TYPE, GasType[selected]
+            ConsumptionProperties.GAS_TYPE, GasType[selected].value
         )
 
     async def async_set_gas_type(self, selected: str):
         """Async set gas type"""
         await self._async_set_consumptions_settings(
-            ConsumptionProperties.GAS_TYPE, GasType[selected]
+            ConsumptionProperties.GAS_TYPE, GasType[selected].value
         )
 
     def get_currency(self) -> Optional[str]:
         """Get gas type"""
         currency = self.consumptions_settings.get(ConsumptionProperties.CURRENCY)
-        if currency in dir(Currency):
+        if currency in list(Currency):
             return Currency(
                 self.consumptions_settings.get(ConsumptionProperties.CURRENCY)
             ).name
@@ -512,20 +520,23 @@ class AristonGalevoDevice(AristonDevice):
     def set_currency(self, selected: str):
         """Set currency"""
         self._set_consumptions_settings(
-            ConsumptionProperties.CURRENCY, Currency[selected]
+            ConsumptionProperties.CURRENCY, Currency[selected].value
         )
 
     async def async_set_currency(self, selected: str):
         """Async set currency"""
         await self._async_set_consumptions_settings(
-            ConsumptionProperties.CURRENCY, Currency[selected]
+            ConsumptionProperties.CURRENCY, Currency[selected].value
         )
 
     def get_gas_energy_unit(self) -> Optional[str]:
         """Get gas energy unit"""
-        return GasEnergyUnit(
-            self.consumptions_settings.get(ConsumptionProperties.GAS_ENERGY_UNIT)
-        ).name
+        gas_energy_unit = self.consumptions_settings.get(ConsumptionProperties.GAS_ENERGY_UNIT)
+        if gas_energy_unit in list(GasEnergyUnit):
+            return GasEnergyUnit(
+                self.consumptions_settings.get(ConsumptionProperties.GAS_ENERGY_UNIT)
+            ).name
+        return None
 
     @staticmethod
     def get_gas_energy_units() -> list[Optional[str]]:
@@ -535,42 +546,42 @@ class AristonGalevoDevice(AristonDevice):
     def set_gas_energy_unit(self, selected: str):
         """Set gas energy unit"""
         self._set_consumptions_settings(
-            ConsumptionProperties.GAS_ENERGY_UNIT, GasEnergyUnit[selected]
+            ConsumptionProperties.GAS_ENERGY_UNIT, GasEnergyUnit[selected].value
         )
 
     async def async_set_gas_energy_unit(self, selected: str):
         """Async set gas energy unit"""
         await self._async_set_consumptions_settings(
-            ConsumptionProperties.GAS_ENERGY_UNIT, GasEnergyUnit[selected]
+            ConsumptionProperties.GAS_ENERGY_UNIT, GasEnergyUnit[selected].value
         )
 
     def get_gas_consumption_for_heating_last_month(self) -> Optional[int]:
-        """Get gas consumption for heating last month"""
+        """Get gas consumption for heatig last month"""
         energy_account_last_month = self.energy_account.get("LastMonth", None)
-        if energy_account_last_month is None:
+        if not energy_account_last_month:
             return None
-        return energy_account_last_month[0]["gas"]
+        return energy_account_last_month[0].get("gas", None)
 
     def get_electricity_consumption_for_heating_last_month(self) -> Optional[int]:
         """Get electricity consumption for heating last month"""
         energy_account_last_month = self.energy_account.get("LastMonth", None)
-        if energy_account_last_month is None:
+        if not energy_account_last_month:
             return None
-        return energy_account_last_month[0]["elect"]
+        return energy_account_last_month[0].get("elect", None)
 
     def get_gas_consumption_for_water_last_month(self) -> Optional[int]:
         """Get gas consumption for water last month"""
         energy_account_last_month = self.energy_account.get("LastMonth", None)
-        if energy_account_last_month is None:
+        if not energy_account_last_month or len(energy_account_last_month) < 2:
             return None
-        return energy_account_last_month[1]["gas"]
+        return energy_account_last_month[1].get("gas", None)
 
     def get_electricity_consumption_for_water_last_month(self) -> Optional[int]:
         """Get electricity consumption for water last month"""
         energy_account_last_month = self.energy_account.get("LastMonth", None)
-        if energy_account_last_month is None:
+        if not energy_account_last_month or len(energy_account_last_month) < 2:
             return None
-        return energy_account_last_month[1]["elect"]
+        return energy_account_last_month[1].get("elect", None)
 
     def set_elect_cost(self, value: float):
         """Set electric cost"""
@@ -648,19 +659,19 @@ class AristonGalevoDevice(AristonDevice):
 
     def set_plant_mode(self, plant_mode: PlantMode):
         """Set plant mode"""
-        self.set_item_by_id(DeviceProperties.PLANT_MODE, plant_mode)
+        self.set_item_by_id(DeviceProperties.PLANT_MODE, plant_mode.value)
 
     async def async_set_plant_mode(self, plant_mode: PlantMode):
         """Async set plant mode"""
-        await self.async_set_item_by_id(DeviceProperties.PLANT_MODE, plant_mode)
+        await self.async_set_item_by_id(DeviceProperties.PLANT_MODE, plant_mode.value)
 
     def set_zone_mode(self, zone_mode: ZoneMode, zone: int):
         """Set zone mode"""
-        self.set_item_by_id(ThermostatProperties.ZONE_MODE, zone_mode, zone)
+        self.set_item_by_id(ThermostatProperties.ZONE_MODE, zone_mode.value, zone)
 
     async def async_set_zone_mode(self, zone_mode: ZoneMode, zone: int):
         """Async set zone mode"""
-        await self.async_set_item_by_id(ThermostatProperties.ZONE_MODE, zone_mode, zone)
+        await self.async_set_item_by_id(ThermostatProperties.ZONE_MODE, zone_mode.value, zone)
 
     def set_comfort_temp(self, temp: float, zone: int):
         """Set comfort temp"""
